Token class abstract

Base class for all authentication tokens.

Implementers

Constructors

Token({required String accessToken, String? refreshToken, String? tokenType = 'bearer'})
{macro token}
const

Properties

accessToken String
The access token string as issued by the authorization server.
final
expiresAt DateTime?
The date the token will expire.
no setter
hashCode int
The hash code for this object.
no setterinherited
refreshToken String?
Token which applications can use to obtain another access token.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenType String?
The type of token this is, typically just the string “bearer”.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited